@@ -97,6 +97,7 @@ import aws_cdk.aws_apigateway
 import aws_cdk.aws_cognito
 import aws_cdk.aws_dynamodb
 import aws_cdk.aws_ec2
+import aws_cdk.aws_events
 import aws_cdk.aws_glue
 import aws_cdk.aws_iam
 import aws_cdk.aws_kinesis
@@ -110,6 +111,7 @@ import aws_cdk.aws_sagemaker
 import aws_cdk.aws_secretsmanager
 import aws_cdk.aws_sns
 import aws_cdk.aws_sqs
+import aws_cdk.aws_wafv2
 
 
 @jsii.data_type(
@@ -469,6 +471,65 @@ class BuildDynamoDBTableWithStreamProps:
         )
 
 
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/core.BuildEventBusProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "event_bus_props": "eventBusProps",
+        "existing_event_bus_interface": "existingEventBusInterface",
+    },
+)
+class BuildEventBusProps:
+    def __init__(
+        self,
+        *,
+        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
+        existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
+    ) -> None:
+        '''
+        :param event_bus_props: Optional user provided props to override the default props for the SNS topic. Default: - Default props are used.
+        :param existing_event_bus_interface: Existing instance of SNS Topic object, providing both this and ``topicProps`` will cause an error. Default: - None.
+        '''
+        if isinstance(event_bus_props, dict):
+            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
+        self._values: typing.Dict[str, typing.Any] = {}
+        if event_bus_props is not None:
+            self._values["event_bus_props"] = event_bus_props
+        if existing_event_bus_interface is not None:
+            self._values["existing_event_bus_interface"] = existing_event_bus_interface
+
+    @builtins.property
+    def event_bus_props(self) -> typing.Optional[aws_cdk.aws_events.EventBusProps]:
+        '''Optional user provided props to override the default props for the SNS topic.
+
+        :default: - Default props are used.
+        '''
+        result = self._values.get("event_bus_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_events.EventBusProps], result)
+
+    @builtins.property
+    def existing_event_bus_interface(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
+        '''Existing instance of SNS Topic object, providing both this and ``topicProps`` will cause an error.
+
+        :default: - None.
+        '''
+        result = self._values.get("existing_event_bus_interface")
+        return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "BuildEventBusProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/core.BuildGlueJobProps",
     jsii_struct_bases=[],
@@ -865,22 +926,31 @@ class BuildQueueProps:
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/core.BuildS3BucketProps",
     jsii_struct_bases=[],
-    name_mapping={"bucket_props": "bucketProps"},
+    name_mapping={
+        "bucket_props": "bucketProps",
+        "logging_bucket_props": "loggingBucketProps",
+    },
 )
 class BuildS3BucketProps:
     def __init__(
         self,
         *,
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
     ) -> None:
         '''
         :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
+        :param logging_bucket_props: User provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
         '''
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
+        if isinstance(logging_bucket_props, dict):
+            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         self._values: typing.Dict[str, typing.Any] = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
+        if logging_bucket_props is not None:
+            self._values["logging_bucket_props"] = logging_bucket_props
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
@@ -891,6 +961,15 @@ class BuildS3BucketProps:
         result = self._values.get("bucket_props")
         return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
 
+    @builtins.property
+    def logging_bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+        '''User provided props to override the default props for the S3 Logging Bucket.
+
+        :default: - Default props are used
+        '''
+        result = self._values.get("logging_bucket_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -1280,6 +1359,57 @@ class BuildVpcProps:
         )
 
 
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/core.BuildWebaclProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "existing_webacl_obj": "existingWebaclObj",
+        "webacl_props": "webaclProps",
+    },
+)
+class BuildWebaclProps:
+    def __init__(
+        self,
+        *,
+        existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
+        webacl_props: typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps] = None,
+    ) -> None:
+        '''
+        :param existing_webacl_obj: Existing instance of a WAF web ACL, if this is set then the all props are ignored.
+        :param webacl_props: User provided props to override the default ACL props for WAF web ACL.
+        '''
+        if isinstance(webacl_props, dict):
+            webacl_props = aws_cdk.aws_wafv2.CfnWebACLProps(**webacl_props)
+        self._values: typing.Dict[str, typing.Any] = {}
+        if existing_webacl_obj is not None:
+            self._values["existing_webacl_obj"] = existing_webacl_obj
+        if webacl_props is not None:
+            self._values["webacl_props"] = webacl_props
+
+    @builtins.property
+    def existing_webacl_obj(self) -> typing.Optional[aws_cdk.aws_wafv2.CfnWebACL]:
+        '''Existing instance of a WAF web ACL, if this is set then the all props are ignored.'''
+        result = self._values.get("existing_webacl_obj")
+        return typing.cast(typing.Optional[aws_cdk.aws_wafv2.CfnWebACL], result)
+
+    @builtins.property
+    def webacl_props(self) -> typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps]:
+        '''User provided props to override the default ACL props for WAF web ACL.'''
+        result = self._values.get("webacl_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "BuildWebaclProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/core.CfnDomainOptions",
     jsii_struct_bases=[],
@@ -1586,10 +1716,11 @@ class ServiceEndpointTypes(enum.Enum):
     SNS = "SNS"
     SQS = "SQS"
     S3 = "S3"
-    STEPFUNCTIONS = "STEPFUNCTIONS"
+    STEP_FUNCTIONS = "STEP_FUNCTIONS"
     SAGEMAKER_RUNTIME = "SAGEMAKER_RUNTIME"
     SECRETS_MANAGER = "SECRETS_MANAGER"
     SSM = "SSM"
+    EVENTS = "EVENTS"
 
 
 @jsii.data_type(
@@ -2039,6 +2170,7 @@ __all__ = [
     "BuildDeadLetterQueueProps",
     "BuildDynamoDBTableProps",
     "BuildDynamoDBTableWithStreamProps",
+    "BuildEventBusProps",
     "BuildGlueJobProps",
     "BuildKinesisAnalyticsAppProps",
     "BuildKinesisStreamProps",
@@ -2049,6 +2181,7 @@ __all__ = [
     "BuildSagemakerNotebookProps",
     "BuildTopicProps",
     "BuildVpcProps",
+    "BuildWebaclProps",
     "CfnDomainOptions",
     "CfnNagSuppressRule",
     "CognitoOptions",
